@@ -1,6 +1,6 @@
 extern crate core;
 
-#[allow(clippy::missing_errors_doc)]
+#[allow(clippy::missing_errors_doc, clippy::missing_panics_doc, clippy::module_name_repetitions)]
 
 pub mod wtcsv;
 pub mod diff;
