@@ -20,15 +20,14 @@ pub struct WTCSV {
 impl WTCSV {
 	pub fn new_from_path(path: impl AsRef<Path>, name: &str) -> Result<Self, Box<dyn Error>> {
 		let file = fs::read_to_string(path)?;
-		WTCSV::new_from_file(file, name)
+		WTCSV::new_from_file(&file, name)
 	}
 
 	/// Creates a record from a supported file
-	#[must_use]
-	pub fn new_from_file(file: String, name: &str) -> Result<Self, Box<dyn Error>> {
+	pub fn new_from_file(file: &str, name: &str) -> Result<Self, Box<dyn Error>> {
 		let crlf = file.contains(CRLF);
 
-		let header = Header::from_file(&file)?;
+		let header = Header::from_file(file)?;
 
 		let mut records: Vec<String> = Vec::new();
 
@@ -37,6 +36,7 @@ impl WTCSV {
 
 		let chars = file.chars().collect::<Vec<char>>();
 
+		#[allow(clippy::needless_range_loop)]
 		for i in 0..chars.len() {
 			let char = chars[i];
 
@@ -49,7 +49,7 @@ impl WTCSV {
 			// Subtracting one as there is always one less delimiter compared to headers
 			if delim_count == header.len - 1 && (char == RECORD_SEP) { // End of record is indicated by \n as CLRF terminates with that
 				// Cropping away the last two chars as they are CLRF - \r\n chars
-				let new_buffer = buffer.clone()[..buffer.len() - if crlf {2 } else {1}].to_owned();
+				let new_buffer = buffer.clone()[..buffer.len() - if crlf { 2 } else { 1 }].to_owned();
 				records.push(new_buffer);
 				buffer.clear();
 				delim_count = 0;
@@ -75,7 +75,6 @@ impl WTCSV {
 	}
 
 	/// Inserts record into struct from file, returns result if the process was successful
-	#[must_use]
 	pub fn insert_record(&mut self, record: &str) -> Result<(), Box<dyn Error>> {
 		let serialized_record = Record::from_wt_string(record);
 		if self.header.len == serialized_record.items.len() {
@@ -119,7 +118,6 @@ impl WTCSV {
 		file
 	}
 
-	#[must_use]
 	pub fn edit_record_by_id(&mut self, id: &str, new_target: &str) -> Result<(), Box<dyn Error>> {
 		// Creating static baseline that does not affect &mut self
 		let baseline = self.clone();
@@ -130,7 +128,7 @@ impl WTCSV {
 			map.insert(&record.items[0], i);
 		}
 
-		let result = map.get(id).ok_or(WTCSVError::RecordIdNotFound(id.to_string(), self.name.clone()))?;
+		let result = map.get(id).ok_or_else(|| WTCSVError::RecordIdNotFound(id.to_string(), self.name.clone()))?;
 		for (i, _) in baseline.records[*result].items.iter().enumerate() {
 			if i != 0 {
 				self.records[*result].items[i] = new_target.to_string();
@@ -140,7 +138,6 @@ impl WTCSV {
 	}
 
 	/// The fastest for smaller files, currently the fastest
-	#[must_use]
 	pub fn get_record_by_id_vec(&self, id: &str) -> Result<Record, Box<dyn Error>> {
 		for record in &self.records {
 			if record.items[0] == id {
@@ -152,19 +149,44 @@ impl WTCSV {
 
 	/// Returns list of ids matching provided case
 	/// Utilizing a looped hashmap this function should run at O(N * Nr) Nr being the amount of attributes
+	#[must_use]
 	pub fn get_ids_by_parameter(&self, parameter: &str) -> Vec<String> {
 		let mut map = HashMap::new();
 		let mut known = HashSet::new();
 		for record in &self.records {
 			for item in &record.items {
 				if map.get(item).is_some() && item == parameter {
-					known.insert(record.items[0].clone());
+					known.insert(record.items[0].as_str());
 				}
 				map.insert(item, &record.items[0]);
 			}
 		}
-		known.insert(map.get(&parameter.to_string()).unwrap().to_string());
-		let mut result: Vec<String> = known.iter().map(|x|x.to_owned()).collect();
+		if let Some(item) = map.get(&parameter.to_string()) {
+			known.insert(item);
+		}
+		let mut result: Vec<String> = known.iter().map(std::string::ToString::to_string).collect();
+		result.sort();
+		result
+	}
+	/// Equal as [``get_ids_by_parameter``](WTCSV) with the exception that it takes an (empty) buffer to greatly speed up repeated calls to this function
+	pub fn get_buffered_ids_by_parameter(&self, parameter: &str, buffer: &mut HashMap<String, String>) -> Vec<String> {
+		if buffer.is_empty() {
+			for record in &self.records {
+				for item in &record.items {
+					buffer.insert(item.clone(), record.items[0].clone());
+				}
+			}
+		}
+		let mut known = HashSet::new();
+		for record in &self.records {
+			for item in &record.items {
+				if buffer.get(item).is_some() && item == parameter {
+					known.insert(record.items[0].as_str());
+				}
+			}
+		}
+		known.insert(buffer.get(&parameter.to_string()).unwrap());
+		let mut result: Vec<String> = known.iter().map(std::string::ToString::to_string).collect();
 		result.sort();
 		result
 	}
@@ -173,9 +195,9 @@ impl WTCSV {
 #[cfg(test)]
 #[allow(unused_variables, deprecated)]
 mod tests {
+	use std::collections::HashMap;
 	#[allow(unused_imports)]
 	use std::fs;
-	use std::time::Instant;
 
 	use crate::wtcsv::core::wtcsv::WTCSV;
 
@@ -194,7 +216,7 @@ mod tests {
 	#[test]
 	fn core_to_file() {
 		let file = fs::read_to_string("lang/_common_languages.csv").unwrap();
-		let wtcsv = WTCSV::new_from_file(file.clone(), "units").unwrap();
+		let wtcsv = WTCSV::new_from_file(&file.clone(), "units").unwrap();
 
 		assert_eq!(file, wtcsv.export_to_file())
 	}
@@ -202,7 +224,7 @@ mod tests {
 	#[test]
 	fn edit_record() {
 		let file = fs::read_to_string("lang/_common_languages.csv").unwrap();
-		let mut wtcsv = WTCSV::new_from_file(file.clone(), "_common_languages").unwrap();
+		let mut wtcsv = WTCSV::new_from_file(&file.clone(), "_common_languages").unwrap();
 
 		wtcsv.edit_record_by_id("country_china", "west-taiwan").unwrap();
 
@@ -214,7 +236,7 @@ mod tests {
 	#[test]
 	fn get_good_record_vec() {
 		let file = fs::read_to_string("lang/units.csv").unwrap();
-		let wtcsv = WTCSV::new_from_file(file.clone(), "units").unwrap();
+		let wtcsv = WTCSV::new_from_file(&file.clone(), "units").unwrap();
 
 		let result = wtcsv.get_record_by_id_vec("ussr_mpk_201k_2");
 
@@ -224,7 +246,7 @@ mod tests {
 	#[test]
 	fn get_bad_record_vec() {
 		let file = fs::read_to_string("lang/_common_languages.csv").unwrap();
-		let wtcsv = WTCSV::new_from_file(file.clone(), "_common_languages").unwrap();
+		let wtcsv = WTCSV::new_from_file(&file.clone(), "_common_languages").unwrap();
 
 		assert_eq!(true, wtcsv.get_record_by_id_vec("country_fake").is_err())
 	}
@@ -232,11 +254,26 @@ mod tests {
 	#[test]
 	fn get_id_by_parameter() {
 		let file = fs::read_to_string("lang/units.csv").unwrap();
-		let wtcsv = WTCSV::new_from_file(file.clone(), "units").unwrap();
+		let wtcsv = WTCSV::new_from_file(&file.clone(), "units").unwrap();
 
 		let mut result = wtcsv.get_ids_by_parameter("Flusi 1");
 
 		result.sort();
 		assert_eq!(["germ_rdm242_1", "germ_rdm242_shop"], result.as_slice());
 	}
+
+	#[test]
+	fn get_buffered_id_by_parameter() {
+		let file = fs::read_to_string("lang/units.csv").unwrap();
+		let wtcsv = WTCSV::new_from_file(&file.clone(), "units").unwrap();
+
+		let mut buffer = HashMap::new();
+		let mut result = wtcsv.get_buffered_ids_by_parameter("Flusi 1", &mut buffer);
+		let mut other_result = wtcsv.get_buffered_ids_by_parameter("M8A1", &mut buffer);
+
+		result.sort();
+		other_result.sort();
+		assert_eq!(["germ_rdm242_1", "germ_rdm242_shop"], result.as_slice());
+		assert_eq!(["us_m8a1_1", "us_m8a1_shop"], other_result.as_slice());
+	}
 }
\ No newline at end of file
